==> eg_particle_interactions-v0.8-fabric-mc1.21.8-sources.jar: games/enchanted/eg_particle_interactions/common/particle/splash/LavaSplash.java <==
package games.enchanted.eg_particle_interactions.common.particle.splash;

import net.minecraft.class_2398;
import net.minecraft.class_2400;
import net.minecraft.class_4002;
import net.minecraft.class_638;
import net.minecraft.class_703;
import net.minecraft.class_707;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class LavaSplash extends BucketSplash {
    public LavaSplash(class_638 level, double x, double y, double z, double xSpeed, double ySpeed, double zSpeed, class_4002 spriteSet) {
        super(level, x, y, z, xSpeed, ySpeed, zSpeed, spriteSet);
    }

    @Override
    public void method_3070() {
        super.method_3070();
        if (!this.field_3843) {
            float percentAge = (float) this.field_3866 / this.field_3847;
            if (this.field_3840.method_43057() < percentAge * 1.5 && this.field_3840.method_43057() > 0.5f) {
                this.field_3851.method_8406(class_2398.field_11251, this.field_3874, this.field_3854, this.field_3871, this.field_3852, this.field_3869, this.field_3850);
            }
        }
    }
    
    @Override
    public void randomOnParticleLand() {
        super.randomOnParticleLand();
        this.field_3851.method_8406(class_2398.field_11251, field_3874, field_3854, field_3871, 0, 0.03, 0);
    }

    public static class Provider implements class_707<class_2400> {
        private final class_4002 spriteSet;

        public Provider(class_4002 spriteSet) {
            this.spriteSet = spriteSet;
        }

        @Nullable
        @Override
        public class_703 createParticle(@NotNull class_2400 type, @NotNull class_638 level, double x, double y, double z, double xSpeed, double ySpeed, double zSpeed) {
            return new LavaSplash(level, x, y, z, xSpeed, ySpeed, zSpeed, spriteSet);
        }
    }
}

==> eg_particle_interactions-v0.8.4-fabric-mc1.21.8-sources.jar: games/enchanted/eg_particle_interactions/common/particle/splash/LavaSplash.java <==
package games.enchanted.eg_particle_interactions.common.particle.splash;

import net.minecraft.class_2398;
import net.minecraft.class_2400;
import net.minecraft.class_4002;
import net.minecraft.class_638;
import net.minecraft.class_703;
import net.minecraft.class_707;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class LavaSplash extends BucketSplash {
    public LavaSplash(class_638 level, double x, double y, double z, double xSpeed, double ySpeed, double zSpeed, class_4002 spriteSet) {
        super(level, x, y, z, xSpeed, ySpeed, zSpeed, spriteSet.method_18139(level.field_9229));
    }

    @Override
    public void method_3070() {
        super.method_3070();
        if (!this.field_3843) {
            float percentAge = (float) this.field_3866 / this.field_3847;
            if (this.field_3840.method_43057() < percentAge * 1.5 && this.field_3840.method_43057() > 0.5f) {
                this.field_3851.method_8406(class_2398.field_11251, this.field_3874, this.field_3854, this.field_3871, this.field_3852, this.field_3869, this.field_3850);
            }
        }
    }
    
    @Override
    public void randomOnParticleLand() {
        super.randomOnParticleLand();
        this.field_3851.method_8406(class_2398.field_11251, field_3874, field_3854, field_3871, 0, 0.03, 0);
    }

    public static class Provider implements class_707<class_2400> {
        private final class_4002 spriteSet;

        public Provider(class_4002 spriteSet) {
            this.spriteSet = spriteSet;
        }

        @Override
        public @Nullable class_703 createParticle(
            class_2400 type,
            class_638 level,
            double x,
            double y,
            double z,
            double xSpeed,
            double ySpeed,
            double zSpeed
            //? if minecraft: > 1.21.8 {
            /*, RandomSource random
            *///?}
        ) {
            return new LavaSplash(level, x, y, z, xSpeed, ySpeed, zSpeed, spriteSet);
        }
    }
}
